@@ -1,12 +1,12 @@
 from typing import Optional
 
-from MSApi.mixin.AttributeMixin import AttributeMixin
+from MSApi.mixin import AttributeMixin, SalePricesMixin
 from MSApi.Assortment import Assortment
 from MSApi.ProductFolder import ProductFolder
 from MSApi.ObjectMS import check_init
 
 
-class Product(Assortment, AttributeMixin):
+class Product(Assortment, AttributeMixin, SalePricesMixin):
 
     _type_name = 'product'
 
